@@ -1,7 +1,9 @@
 pub mod exc;
-mod lexer;
-mod parser;
+pub mod lexer;
+pub mod parser;
 pub mod var;
+pub mod _mem;
+
 //use std::time::Instant;
 pub fn run_parsed(code: parser::Parse) -> var::Var {
     exc::inter([0, code.parsed_data.len()], code)
@@ -16,7 +18,7 @@ pub fn run(code: String) -> var::Var {
     let lex = lexer::lext(code);
     let parsed_code = parser::parser(lex);
     //drop(lex);
-    //let now = Instant::now();
+   // let now = Instant::now();
     let x = exc::inter([0, parsed_code.parsed_data.len()], parsed_code);
     //println!("Extime: {}", now.elapsed().as_millis());
     x
